

Version information from `QPtomographer` members
------------------------------------------------


.. py:data:: __version__

   The full version string corresponding to the loaded `QPtomographer` package,
   for instance ``"1.2beta3"``.

.. py:data:: version_info

   A named tuple `(major, minor)` with the major and minor versions of the
   currently loaded package, as integers.

